==> rubygem-backup-4.2.3.txz: usr/local/lib/ruby/gems/2.2/gems/backup-4.2.3/README.md <==
Backup v4.x
===========

[![Code Climate](https://codeclimate.com/github/backup/backup.png)](https://codeclimate.com/github/backup/backup)
[![Build Status](https://travis-ci.org/backup/backup.svg?branch=master)](https://travis-ci.org/backup/backup)
[![Join the chat at https://gitter.im/backup/backup](https://badges.gitter.im/Join%20Chat.svg)][Gitter]

Backup is a system utility for Linux and Mac OS X, distributed as a RubyGem, that allows you to easily perform backup
operations. It provides an elegant DSL in Ruby for _modeling_ your backups. Backup has built-in support for various
databases, storage protocols/services, syncers, compressors, encryptors and notifiers which you can mix and match. It
was built with modularity, extensibility and simplicity in mind.

[Installation][] &middot; [Release Notes][] &middot; [Documentation][] &middot; [Issues][] &middot; [Features][] &middot; [Chat][Gitter]

Please use the Backup features [issue tracker][Features] to suggest new features.
Only use the Backup gem [issue tracker][Issues] for bugs and other issues.
We're also available on [Gitter][] for questions and problems.

**Copyright (c) 2009-2015 [Michael van Rooijen][] ( [@meskyanichi][] )**  
Released under the **MIT** [License](LICENSE.md).

[Installation]:  http://backup.github.io/backup/v4/installation
[Release Notes]: http://backup.github.io/backup/v4/release-notes
[Documentation]: http://backup.github.io/backup/v4
[Issues]: https://github.com/backup/backup/issues
[Features]: https://github.com/backup/backup-features/issues
[Gitter]: https://gitter.im/backup/backup?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge
[Michael van Rooijen]: http://michaelvanrooijen.com
[@meskyanichi]: http://twitter.com/#!/meskyanichi

==> rubygem-backup-4.4.1_1.txz: usr/local/lib/ruby/gems/2.7/gems/backup-4.4.1/README.md <==
Backup v4.x
===========

[![Code Climate](https://codeclimate.com/github/backup/backup.png)](https://codeclimate.com/github/backup/backup)
[![Build Status](https://travis-ci.org/backup/backup.svg?branch=master)](https://travis-ci.org/backup/backup)
[![Join the chat at https://gitter.im/backup/backup](https://badges.gitter.im/Join%20Chat.svg)][Gitter]

Backup is a system utility for Linux and Mac OS X, distributed as a RubyGem, that allows you to easily perform backup
operations. It provides an elegant DSL in Ruby for _modeling_ your backups. Backup has built-in support for various
databases, storage protocols/services, syncers, compressors, encryptors and notifiers which you can mix and match. It
was built with modularity, extensibility and simplicity in mind.

[Installation][] &middot; [Release Notes][] &middot; [Documentation][] &middot; [Issues][] &middot; [Features][] &middot; [Chat][Gitter]

Please use the Backup features [issue tracker][Features] to suggest new features.
Only use the Backup gem [issue tracker][Issues] for bugs and other issues.
We're also available on [Gitter] for questions and problems.

**Copyright (c) 2009-2016 [Michael van Rooijen][] ( [@mrrooijen] )**  
Released under the **MIT** [LICENSE](LICENSE).

[Installation]:  http://backup.github.io/backup/v4/installation
[Release Notes]: http://backup.github.io/backup/v4/release-notes
[Documentation]: http://backup.github.io/backup/v4
[Issues]: https://github.com/backup/backup/issues
[Features]: https://github.com/backup/backup-features/issues
[Gitter]: https://gitter.im/backup/backup?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge
[Michael van Rooijen]: http://github.com/mrrooijen
[@mrrooijen]: http://twitter.com/mrrooijen
